;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "agent-shell" "20260616.807"
  "Native agentic integrations for Claude Code, Gemini CLI, etc."
  '((emacs       "29.1")
    (shell-maker "0.93.1")
    (acp         "0.12.2"))
  :url "https://github.com/xenodium/agent-shell"
  :commit "c03acf250baebcb05439d15f5b0d3e1647115bdc"
  :revdesc "c03acf250bae")
